/*
    Copyright

   (standard Lucent Technologies copyright)



*/
/* This Rexx Script will place the correct config.sys statements
   into your config.sys file to give your system the correct drivers and
   program for your Lucent Technologies modem.

   Your old config.sys will be renamed config.lt.

   The script will also modify the snoop.lst file in the \os2\boot directory
   on your OS/2 drive, and rename the old snoop.lst to snoop.lt.


*/

/* Copy files from Source to Destination

   Source is assumed to be the current directory
   Destination is:

     X:\os2 for applications and ini file
     X:\os2\boot for driver  and snooper files

   Where X: is the drive OS2 is installed on.

*/

call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
call SysLoadFuncs

Signal ON HALT

infile = "ltmodem.ini"

iniheader. = 0


langstr = translate(VALUE('lang',,'OS2ENVIRONMENT'))
BootDrive = filespec('Drive',Value('USER_INI',,'OS2ENVIRONMENT'))

call ParseIniFile

/* check to see if langauage is set in [DialogText] section of .ini */
lang = getentry( 'DialogText' 'Language')
/* If langauge was not set, try and determine language from 'lang' environment variable */
if lang = '' then
   lang = getentry( 'OS2LanguageCode' langstr)
/* Cannot determine language so default to english */
if lang = '' then
   lang = 'English'

say '5.36' /* version */

call modifyConfigSys
call modifySnoopLst
call forceHArdwareRescan
call killmonitor
call copyFiles
call createIcon
say
say getentry( lang 'OS2RestartText')

say
say getentry( lang 'ExitInstText')

pull

exit

/* Modify Config.sys */
modifyConfigSys: Procedure expose BootDrive iniheader. lang

   outfile = BootDrive'\config.sys'
   infile  = BootDrive'\config.lt'
   tempfile=systempfilename(BootDrive'\config.???')

   if stream(outfile, 'C', 'Query Exists') = '' then do
      say getentry( lang 'MissingConfigFileText')' 'outfile
      exit
   end

   say getentry(lang 'ChangeConfigFileText')' 'infile
   say
   '@copy 'outfile infile '> nul'   /* Create backup file */

   /* We will create a new config.sys using the tempfile name.
      Once we have finished without error, we will copy tempfile
      to config.sys
   */

   rc=lineout(tempfile,'REM   LTMDMOS2 install - The device=ltmdmos2.sys line must come prior')
   rc=lineout(tempfile,'REM   to the device=com.sys line')
   rc=lineout(tempfile,'DEVICE='BootDrive'\os2\boot\ltmdmos2.sys')
   rc=lineout(tempfile,'RUN='BootDrive'\os2\boot\lt_mon.exe')
   rc=lineout(tempfile,'REM   end LTMDMOS2 install')

   do while lines(infile)
      line=linein(infile)
      parse upper value line with keyword "=" therest
      if (keyword=DEVICE) then do
         if pos(' ',therest) = 0 then
            pathname=therest
         else
            pathname=substr(therest,1,pos(' ',therest))

         lpname=pathname
         do while pos('\',pathname)\=0
            parse UPPER value pathname with apath '\' pathname
         end
         parse value pathname with driver " " params
         if driver = LTMDMOS2.SYS then do
            rc=lineout(tempfile,'REM The following line "REM"ed by LT install')
            rc=lineout(tempfile,'REM 'line)
         end
         else
            rc=lineout(tempfile, line)
      end /* if keyword=DEVICE */

      else if (keyword=RUN) then do
         if pos(' ',therest) = 0 then
            pathname=therest
         else
            pathname=substr(therest,1,pos(' ',therest))

         lpname=pathname
         do while pos('\',pathname)\=0
            parse UPPER value pathname with apath '\' pathname
         end
         parse value pathname with program " " params
         if program = LT_MON.EXE then do
            rc=lineout(tempfile,'REM The following line "REM"ed by LT install')
            rc=lineout(tempfile,'REM 'line)
         end
         else
            rc=lineout(tempfile, line)
      end /* if keyword=RUN */
      else
         rc=lineout(tempfile, line)
   end /* while loop for lines in config.lt */

   /* close tempfile */
   rc=lineout(tempfile)

   /* copy the newly created tempfile to config.sys */
   '@copy 'tempfile outfile '> nul'
   '@del 'tempfile' > nul'

return

/* Modify snoop.lst */
modifySnoopLst: Procedure expose BootDrive iniheader. lang

   outfile = BootDrive'\os2\boot\snoop.lst'
   infile  = BootDrive'\os2\boot\snoop.lt'
   tempfile=systempfilename(BootDrive'\os2\boot\snoop.???')

   say getentry(lang 'ChangeSnoopFileText')' 'infile
   say
   '@copy 'outfile infile '> nul'   /* Create backup file */


   FOUND_SERIAL_SNOOPER=FALSE
   LEFT_EARLY = FALSE
   ADD_LTMODEM_SNOOPER = TRUE

   do while lines(infile)
      line=linein(infile)
      if line='ltos2snp.snp' then
         ADD_LTMODEM_SNOOPER = FALSE
      else if line='serial.snp' then do
         FOUND_SERIAL_SNOOPER=TRUE
         if ADD_LTMODEM_SNOOPER = TRUE then do
            rc=lineout(tempfile, '; Lucent Technologies BIOS Modem snooper')
            rc=lineout(tempfile, '; This line must be placed prior to serial.snp')
            rc=lineout(tempfile, 'ltos2snp.snp')
         end
      end
      else if line='; Note: Place additional snoopers above this line' then do
         LEFT_EARLY=TRUE
         LEAVE
      end
      rc=lineout(tempfile, line)
   end /* while loop for lines in config.lt */

   if (FOUND_SERIAL_SNOOPER = FALSE) then do
         rc=lineout(tempfile, '; Lucent Technologies BIOS Modem snooper')
         rc=lineout(tempfile, 'ltos2snp.snp')
   end

   if (LEFT_EARLY = TRUE) then
      rc=lineout(tempfile, line)

   do while lines(infile) /* The LEAVE instruction in the loop above may leave
                             snoop.lt unfinished.  */
      line=linein(infile)
      rc=lineout(tempfile, line)
   end /* while loop for lines in config.lt */

   /* close tempfile */
   rc=lineout(tempfile)

   /* copy the newly created tempfile to snoop.lst */
   '@copy 'tempfile outfile '> nul'
   '@del 'tempfile' > nul'

return

/* Force a hardware rescan on the next boot */
forceHardwareRescan: Procedure expose BootDrive iniheader. lang

   say GetEntry( lang 'ForceHWRescanText')
   say
   '@del 'BootDrive'\os2\boot\previous.dat 1> nul 2> nul'
return

/* Copy files from installation source to correct destinations */
copyfiles: Procedure expose BootDrive

   'copy ltcs.exe 'BootDrive'\os2\ '
   'copy ltmdmos2.sys 'BootDrive'\os2\boot\ '
   'copy ltos2snp.snp 'BootDrive'\os2\boot\ '
   'copy lt_mon.exe 'BootDrive'\os2\boot\ '
   'copy ltmodem.ini 'BootDrive'\os2\ '

return


killmonitor: Procedure expose BootDrive
   monitorprg = BootDrive'\os2\boot\lt_mon.exe'

   '@del 'monitorprg '1> nul 2>nul'
   if stream(monitorprg, 'C', 'Query Exists') \= '' then do
      '@lt_mon.exe > nul' /* This should kill the current version in \os2\boot */
   end

return


/* Create the icon in the 'System Setup' Folder */
createIcon: Procedure expose BootDrive lang iniheader. lang

   class = "WPPROGRAM"
   cr = '0d'x
   lf = '0a'x


   title = getentry(lang 'AppletName')

   location = "<WP_CONFIG>"
   objectid = "<LT_CS_APP>"

   say
   say GetEntry( lang 'CreateIconText') " '"title"'"
   rc=SysDestroyObject(objectid)
   rc=Syscreateobject(class, title, location, "EXENAME="BootDrive"\os2\ltcs.exe;STARTUPDIR="BootDrive"\os2;OBJECTID="objectid)

return

ParseIniFile: Procedure Expose iniheader. infile

   If Stream( infile, 'C', 'QUERY EXISTS' ) = '' then do
      say getentry( lang 'MissingFileText')
      exit
   end

   i = 0
   j = 0

   do while lines(infile)
      line = linein(infile)
      /*
      if header
         attach new header
      else if element
         attach new element
      */
      if line='' then iterate
      if substr(line,1,1) = ';' then iterate
      if (substr(line,1,1) = '[') & (substr(line,length(line),1) = ']') then do
         i=i+1
         iniheader.i = strip(translate(line,'  ','[]'))
         j = 0
      end
      else do
         parse value line with key '=' value
         if value <> '' then do
            value = strip(translate(value,' ','"'))
            j = j+1
            iniheader.i.element.j.tkey = key
            iniheader.i.element.j.tvalue = value
            iniheader.i.element.0 = j
         end
      end
   end
   iniheader.0 = i
   /* close file */
   call lineout(infile)

return


DumpIniFile: Procedure Expose iniheader.

do i = 1 to iniheader.0
   say iniheader.i
   do j = 1 to iniheader.i.element.0
   say '   'iniheader.i.element.j.tkey'='iniheader.i.element.j.tvalue
   end
end

return


GetEntry: Procedure expose iniheader.

parse ARG header key

do i = 1 to iniheader.0
   if header=iniheader.i then
      do j = 1 to iniheader.i.element.0
         if key =iniheader.i.element.j.tkey then
            return (iniheader.i.element.j.tvalue)
      end
end
return ('')

HALT:
  exit

